Summary:     The base package for the ISC DHCP server/relay/client
Name:        dhcp
Version:     3.0.2
Release:     6.pp
License:     GPL
Group:       Environment/Console
Source0:     ftp://ftp.isc.org/isc/%{name}/%{name}-%{version}.tar.gz
Source1:     dhcpd.init
Source2:     dhcrelay.init
Source3:     dhcpd.sysconfig
Source4:     dhcrelay.sysconfig
Patch0:      %{name}-site_conf.patch
Patch1:      %{name}-dhclient_linux.patch
URL:         http://www.isc.org/products/DHCP/
Buildroot:   /var/tmp/%{name}-root
Vendor:      ISC
Packager:    Peter Pramberger <peter.pramberger@member.fsf.org>
Requires:    glibc
Provides:    %{name}.pp
Prereq:      /bin/bash /sbin/chkconfig
BuildPrereq: gcc >= 2.96 /bin/mkdir /usr/bin/make /usr/bin/install
BuildPrereq: kernel > 2.4 glibc-devel
ExclusiveOS: linux

%description
DHCP (Dynamic Host Configuration Protocol) is a protocol which allows
individual devices on an IP network to get their own network configuration
information (IP address, subnetmask, broadcast address, etc.) from a
DHCP server. The overall purpose of DHCP is to make it easier to administer
a large network. The %{name} package includes the base components needed for
the Internet Software Consortium (ISC) DHCP server, relay, client and devel
packages.


%package devel
Summary:     Development headers and libraries for the dhcpctl API
Group:       Development/Libraries
Requires:    %{name} = %{version}-%{release} %{name}.pp
Provides:    %{name}-devel.pp

%package server
Summary:     The ISC DHCP server
Group:       Environment/Daemons
Requires:    %{name} = %{version}-%{release} %{name}.pp
Provides:    %{name}-server.pp
Conflicts:   %{name}-relay = %{version}-%{release} %{name}-relay.pp

%package relay
Summary:     The ISC DHCP relay
Group:       Environment/Daemons
Requires:    %{name} = %{version}-%{release} %{name}.pp
Provides:    %{name}-relay.pp
Conflicts:   %{name}-server = %{version}-%{release} %{name}-server.pp

%package client
Summary:     The ISC DHCP client
Group:       Environment/Console
Requires:    %{name} = %{version}-%{release} %{name}.pp
Provides:    %{name}-client.pp


%description devel
The %{name}-devel package contains all of the libraries and headers for
developing with the Internet Software Consortium (ISC) dhcpctl API.

%description server
The %{name}-server package contains the Internet Software Consortium
(ISC) DHCP server for various UNIX operating systems.  It allows a UNIX
machine to serve DHCP requests from the network.

%description relay
The %{name}-relay package contains the Internet Software Consortium
(ISC) relay agent for DHCP packets. It is used on a subnet with DHCP
clients to "relay" their requests to a subnet that has a DHCP server on
it. Because DHCP packets can be broadcast, they will not be routed off
of the local subnet. The DHCP relay takes care of this for the client.

%description client
The %{name}-client package contains the Internet Software Consortium
(ISC) DHCP client for various UNIX operating systems. It allows a UNIX
machine to obtain it's networking parameters from a DHCP server.

Normally there is no need to install this package since the RedHat
distribution already includes a DHCP client.


%prep
%setup -q
%patch0 -p1
%patch1 -p1


%build
./configure
make \
	CC_OPTIONS="$RPM_OPT_FLAGS -pipe" \
	all


# Do not strip, only compress documentation
%define __os_install_post /usr/lib/rpm/brp-compress


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT/etc/sysconfig
make \
	DESTDIR=$RPM_BUILD_ROOT \
	install
install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/dhcpd
install -m 0755 %{SOURCE2} $RPM_BUILD_ROOT/etc/rc.d/init.d/dhcrelay
install -m 0644 %{SOURCE3} $RPM_BUILD_ROOT/etc/sysconfig/dhcpd
install -m 0644 %{SOURCE4} $RPM_BUILD_ROOT/etc/sysconfig/dhcrelay
touch $RPM_BUILD_ROOT/var/state/dhcp/dhcpd.leases; chmod 0600 $RPM_BUILD_ROOT/var/state/dhcp/dhcpd.leases
touch $RPM_BUILD_ROOT/var/state/dhcp/dhclient.leases; chmod 0600 $RPM_BUILD_ROOT/var/state/dhcp/dhclient.leases
touch $RPM_BUILD_ROOT/etc/dhcpd.conf; chmod 0600 $RPM_BUILD_ROOT/etc/dhcpd.conf
install -m 0644 client/dhclient.conf $RPM_BUILD_ROOT/etc/dhclient.conf.sample
install -m 0644 server/dhcpd.conf $RPM_BUILD_ROOT/etc/dhcpd.conf.sample
install -m 0755 work.linux-*/dhcpctl/cltest $RPM_BUILD_ROOT/usr/bin
install -m 0755 work.linux-*/omapip/svtest $RPM_BUILD_ROOT/usr/bin


%post server
/sbin/chkconfig --add dhcpd
/sbin/chkconfig dhcpd on
if [ -s /etc/dhcpd.conf ]; then
   if [ -f /var/lock/subsys/dhcpd ]; then
      /etc/rc.d/init.d/dhcpd restart
   fi
fi

%post relay
/sbin/chkconfig --add dhcrelay
/sbin/chkconfig dhcrelay on
if [ -f /var/lock/subsys/dhcrelay ]; then
   /etc/rc.d/init.d/dhcrelay restart
fi


%preun server
if [ $1 = 0 ]; then
   /sbin/chkconfig dhcpd off
   /sbin/chkconfig --del dhcpd
   if [ -f /var/lock/subsys/dhcpd ]; then
      /etc/rc.d/init.d/dhcpd stop
   fi
fi

%preun relay
if [ $1 = 0 ]; then
   /sbin/chkconfig dhcrelay off
   /sbin/chkconfig --del dhcrelay
   if [ -f /var/lock/subsys/dhcrelay ]; then
      /etc/rc.d/init.d/dhcrelay stop
   fi
fi


%clean
rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc LICENSE README RELNOTES
%doc doc/IANA* doc/api* doc/*.txt
/usr/bin/*
/usr/share/man/man1/omshell*
/usr/share/man/man5/dhcp-eval*
/usr/share/man/man5/dhcp-options*
%dir %attr(700,root,root) /var/state/dhcp

%files devel
%defattr(-,root,root)
/usr/include/*
/usr/lib/*.*a
/usr/share/man/man3/omapi*
/usr/share/man/man3/dhcpctl*

%files server
%defattr(-,root,root)
%config(noreplace) %attr(600,root,root) /etc/*.conf
/etc/dhcpd.conf.sample
%config(noreplace) /etc/sysconfig/dhcpd
/etc/rc.d/init.d/dhcpd
/usr/sbin/dhcpd
/usr/share/man/man5/dhcpd*
/usr/share/man/man8/dhcpd*
%config(noreplace) %attr(600,root,root) /var/state/dhcp/dhcpd.leases

%files relay
%defattr(-,root,root)
%config(noreplace) /etc/sysconfig/dhcrelay
/etc/rc.d/init.d/dhcrelay
/usr/sbin/dhcrelay
/usr/share/man/man8/dhcrelay*

%files client
%defattr(-,root,root)
/etc/dhclient.conf.sample
/sbin/*
/usr/share/man/man5/dhclient*
/usr/share/man/man8/dhclient*
%config(noreplace) %attr(600,root,root) /var/state/dhcp/dhclient.leases


%changelog
* Sun Mar 06 2005 peter.pramberger@member.fsf.org
- new version 3.0.2
- removed RH62 stuff

* Mon Jun 02 2003 peter.pramberger@member.fsf.org
- new version 3.0pl2
- compiled for RH73
- removed client package

* Thu May 09 2002 peter.pramberger@member.fsf.org
- new version 3.0.1rc9

* Tue Apr 30 2002 peter.pramberger@member.fsf.org
- created

